@@ -11,6 +11,7 @@ from selenium.webdriver.support.wait import WebDriverWait
 from selenium.common.exceptions import TimeoutException, InvalidSessionIdException, NoSuchElementException
 from selenium.webdriver.remote.webdriver import WebDriver, WebElement
 
+from selenium_toolkit.auto_wait import auto_wait
 from selenium_toolkit.utils import create_locator
 
 
@@ -22,6 +23,7 @@ class SeleniumToolKit:
     def driver(self) -> Union[WebDriver, ChromiumDriver]:
         return self.__driver
 
+    @auto_wait
     def goto(self, url: str) -> None:
         self.__driver.get(url=url)
 
@@ -79,13 +81,19 @@ class SeleniumToolKit:
         except NoSuchElementException as e:
             raise e
 
+    @auto_wait
     def click(self, query_selector: str) -> None:
         self.query_selector(query_selector=query_selector).click()
 
+    @auto_wait
     def fill(self, text: str, query_selector: str) -> None:
         element = self.query_selector(query_selector=query_selector)
         element.send_keys(text)
 
+    @auto_wait
+    def clear(self, query_selector: str) -> None:
+        self.query_selector(query_selector=query_selector).clear()
+
     def fill_in_random_time(self, text: str, query_selector: str) -> None:
         element = self.query_selector(query_selector=query_selector)
         for letter in text:
@@ -93,7 +101,7 @@ class SeleniumToolKit:
             element.send_keys(letter)
 
     def clear_and_fill(self, text: str, query_selector: str, random_time=False) -> None:
-        self.query_selector(query_selector=query_selector).clear()
+        self.clear(query_selector=query_selector)
         if random_time:
             self.fill_in_random_time(text=text, query_selector=query_selector)
         else:
